@@ -25,7 +25,7 @@ our @EXPORT = qw(
 	setns CLONE_ALL CLONE_NEWIPC CLONE_NEWNET CLONE_NEWUTS
 );
 
-our $VERSION = '0.04';
+our $VERSION = '1.01';
 
 use constant {
 	CLONE_ALL => 0,
@@ -41,23 +41,20 @@ XSLoader::load('Linux::Setns', $VERSION);
 
 sub setns {
 	my $ret = setns_wrapper($_[0], $_[1]);
-	return 1 if ($ret == 0);
-	if ($ret == 1) {
+	if ($ret == 0) {
+		return 1;
+	} elsif ($ret == 1) {
 		print STDERR "Error: setns() The calling thread did not have the required privilege (CAP_SYS_ADMIN) for this operation\n";
-		return 0;
-	}
-	if ($ret == 9) {
-		print STDERR "Error: setns() fd is not a valid file descriptor\n";
-		return 0;
-	}
-	if ($ret == 12) {
+	} elsif ($ret == 2) {
+		print STDERR "Error: setns() Unable to open file $_[0]\n";
+	} elsif ($ret == 9) {
+		print STDERR "Error: setns() FD is not a valid file descriptor\n";
+	} elsif ($ret == 12) {
 		print STDERR "Error: setns() Cannot allocate sufficient memory to change the specified namespace\n";
-		return 0;
-	}
-	if ($ret == 22) {
-		print STDERR "Error: setns() fd refers to a namespace whose type does not match that specified in nstype, or there is problem with reassociating the the thread with the specified namespace\n";
-		return 0;
+	} elsif ($ret == 22) {
+		print STDERR "Error: setns() FD refers to a namespace whose type does not match that specified in nstype, or there is problem with reassociating the the thread with the specified namespace\n";
 	}
+	return 0;
 }
 
 1;
@@ -66,26 +63,36 @@ __END__
 
 =head1 NAME
 
-Linux::Setns - Perl extension for switching the current prcoess namespace to another namespace pointed by a file descriptor.
+Linux::Setns - Perl extension for switching the current process namespace to another namespace pointed by a path to the ns file descriptor.
 
 =head1 SYNOPSIS
 
-	use Linux::setns qw(setns CLONE_ALL CLONE_NEWIPC CLONE_NEWNET CLONE_NEWUTC);
+	use Linux::setns qw(setns CLONE_ALL CLONE_NEWIPC CLONE_NEWNET CLONE_NEWUTS CLONE_NEWUSER CLONE_NEWPID);
 
-	die "setns() requires root privileges\n" if $<;
+	die "setns() requires root privileges\n" if $>;
 
-	open my $FD, '<', "/proc/PID/ns/mnt" or die "setns(): unable to open FD\n";
+	setns("/proc/PID/ns/mnt", CLONE_ALL);
+	# now your process is in the same namespaces(IPC,NET,UTS,PID,USER,MOUNT) as the /proc/PID/ns/mnt 
 
-	setns($FD, CLONE_ALL);
-	# now your process is in the same namespace as the $FD you have supplied
-	# in this case, you have to previously know what is the type of namespace of that $FD
+	# If you want to change only one of your namespaces you can use any of the bellow examples:
 
-	setns($FD, CLONE_NEWIPC);
-	# Switch your current IPC namespace to the one pointed by $FD
-	setns($FD, CLONE_NEWNET);
-	# Switch your current Network namespace to the one pointed by $FD
-	setns($FD, CLONE_NEWUTC);
-	# Switch your current UTS namespace to the one pointed by $FD
+	# Switch your current Mount namespace to the one pointed by /proc/PID/ns/mnt
+	setns("/proc/PID/ns/mnt", CLONE_NEWMNT);
+
+	# Switch your current IPC namespace to the one pointed by /proc/PID/ns/ipc
+	setns("/proc/PID/ns/ipc", CLONE_NEWIPC);
+
+	# Switch your current Network namespace to the one pointed by /proc/PID/ns/net
+	setns("/proc/PID/ns/net", CLONE_NEWNET);
+
+	# Switch your current UTS namespace to the one pointed by /proc/PID/ns/uts
+	setns("/proc/PID/ns/uts", CLONE_NEWUTS);
+
+	# Switch your current Pid namespace to the one pointed by /proc/PID/ns/pid
+	setns("/proc/PID/ns/pid", CLONE_NEWPID);
+
+	# Switch your current User namespace to the one pointed by /proc/PID/ns/user
+	setns("/proc/PID/ns/user", CLONE_NEWUSER);
 
 =head1 DESCRIPTION
 
@@ -124,10 +131,10 @@ Marian HackMan Marinov, E<lt>hackman@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 by Marian HackMan Marinov
+Copyright (C) 2016 by Marian HackMan Marinov
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.18.1 or,
+it under the same terms as Perl itself, either Perl version 5.10.1 or,
 at your option, any later version of Perl 5 you may have available.
 
 
